A dataset containing a comprehensive list of names mentioned in therecords of the Salem Witchcraft Papers and the correspondent stub indicating the page name associated with them.
long_doc_nameAn object of class data.frame with 3884 rows and 2 columns.
There are 139 separate pages which mention a total of 1392 unique names. 857 individuals were mentioned once. The maximum number of mentions is 85 (John Hathorn, who served as Salem's Magistrate).
Source table
Name of person mentioned